#!/usr/bin/perl
use lib '/home/martin/ethereal/mgmt';

################################################################################
# Created       : Martin Foster
# Modified      : 19-Nov-2006
################################################################################
#
# Colours - Script part of Ethereal Realms, designed to list all colours
# Copyright (C) 2000-2004  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 29-26503 TWP RD 511
#                 Spruce Grove, Alberta
#                 T7Y 1G4
#
#################################################################################

use CGI;							# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use Ethereal::Comm;						# Communications panel
use Ethereal::Database;						# Database handler
use Ethereal::Login;						# Login functionality
use Ethereal::Param;						# Parameter control
use Ethereal::Option;						# Option handling
use Ethereal::Table;						# Table options
use Ethereal::Template;						# Template file

#################################################################################
# Gobal override
#################################################################################
$CGI::POST_MAX=1024 * 50;					# Maximum posts
$CGI::DISABLE_UPLOADS = 1;					# Disable uploads

################################################################################
# Data Members
################################################################################
my $cgi;							# Common gateway interface handle
my $comm;							# Comm panel
my $database;							# Database handle
my $param;							# Parameter handle
my $scriptname;							# Script name
my $table;							# Table handler
my $tmpl;							# Template handler

my $code;							# Individual code
my $name;							# Individual name

my @names;							# Colour names

my %codes;							# Colour codes
my %realm;							# Realm hash


################################################################################
# Program Area
################################################################################

	# Initial handles
	$cgi      = new CGI;
	$database = new Ethereal::Database();

	# Connect and fetch
	$database->Connect($cgi);

	# Parameter handling
	$param    = new Ethereal::Param($database, $cgi);
	$param->GetParam();

	
	# Database handles
	my $data  = $database->{'HANDLE'};
	my $statement;

	# Dependant handles
	$table    = new Ethereal::Table($cgi);
	$tmpl     = new Ethereal::Template(\%realm);
	$comm     = new Ethereal::Comm($database, $cgi, $tmpl);


	# Connect with hash
	$database->GetHashRealm(\%realm);


	# Retreive lists
	@names = $comm->FontSelectColor($param);


	# Generate hash
	# Prepare and execute
	$database->Pull(\$statement, "SELECT 
		 FontName,
		 FontCode
		FROM Font
		WHERE FontType=?", 'color');
	
	# Cycle through
	while (($name, $code) = $statement->fetchrow())
	{
		# Create elements
		$codes{$name} = $code;
	}

	# Finish
	$statement->finish();


	# HTML display
	# Document header
	print $cgi->header();
	print $database->FetchRealmHeader($param->{'ROOM'}), "\n";

	# Table top
	$table->MakeTop();
	
	# Cycle through
	foreach $name (@names) 
	{
		# Display information
		$table->MakeValid("<B><FONT COLOR=\"$codes{$name}\">$name</FONT></B>", "<FONT COLOR=\"$codes{$name}\">$name</FONT>");
	}

	# Table bottom
	$table->MakeBottom();

	# Document footer
	print $database->FetchRealmFooter($param->{'ROOM'}), "\n";
